<?php
/* Ĉi tiu dosiero estas parto de Pâturage
 * 
 * Copyright (C) 2007 - Guillaume Savaton <llumeao@gmail.com>
 * 
 * Pâturage  estas libera programo;  vi  povas  ĝin  pludistribui  kaj/aŭ
 * modifi je la  kondiĉoj de la GNUa Ĝenerala Publika Permesilo, eldonita
 * de «Free Software Foundation», laŭ la versio 2 de tiu Permesilo aŭ, se
 * vi preferas, ajna posta versio.
 * 
 * Ni distribuas  ĉi tiun  programon esperante  ke ĝi estos  utila, tamen
 * SEN IA AJN GARANTIO,  i.a. sen la implica garantio pri SURMERKATIGEBLO
 * aŭ  TAŬGECO POR IU KONKRETA CELO. Pliajn  detalojn  vidu  en  la  GNUa
 * Ĝenerala Publika Permesilo.
 * 
 * Ekzemplero  de  la  GNUa  Ĝenerala Publika    Permesilo   devas   esti
 * liverita al vi kun ĉi tiu programo; ricevis, turnu vin al
 * 
 * Free Software Foundation
 * 51 Franklin Street, Fifth Floor
 * Boston, MA 02110-1301, USA
 * ------------------------------------------------------------------- */
?>
<?php
   require_once('klasoj/artikla-vidajho.php');

   /**
    * Vidaĵo de dosiero
    *
    * Tiu klaso provizas funkcioj por vidigi atributojn de dosieroj.
    */
   class PGDosieraVidajho extends PGArtiklaVidajho {

      /**
       * @name Konstruiloj
       */

      //@{

      /**
       * Ĉefa konstruilo
       *
       * Tiu funkcio konstruas novan vidaĵon por la provizita dosiero.
       *
       * @param $dosiero La vidigota dosiero
       */
      function PGDosieraVidajho($dosiero) {
         $this->PGArtiklaVidajho($dosiero);
      }

      //@}

      /**
       * @name Atingiloj
       */

      //@{

      /**
       * Liveru la URL-on por la specifita ago
       *
       * Tiu funkcio liveras la URL-on, per kiu oni povas fari la specifan agon.
       *
       * Eblaj valoroj por la argumento $ago estas:
       *    - 'hejmen'
       *    - 'redaktu'
       *    - 'forigu'
       *    - 'vidigu'
       *    - 'elshutu'
       *
       * @param $ago La identigilo de dosier-rilata ago
       * @return La URL-on por la specifita ago
       */
      function leguURLonPorAgo($ago) {
         global $kunteksto;
         if($ago == 'elshutu')
            return $kunteksto->leguURLonAlDosiero($this->_artiklo);
         else
            return parent::leguURLonPorAgo($ago);
      }

      /**
       * Liveru la tekston de helpilo por la specifita ago
       *
       * Tiu funkcio liveras ĉenon kun la ŝpruchelpilo vidigota ĉe la ligo aŭ piktogramo
       * por la specifita ago.
       * La teksto de la helpilo estas liverota en la lingvo specifita en la agordoj
       * de Pâturage.
       *
       * Eblaj valoroj por la argumento $ago estas:
       *    - 'hejmen'
       *    - 'redaktu'
       *    - 'forigu'
       *    - 'vidigu'
       *    - 'elshutu'
       *
       * @param $ago La identigilo de dosier-rilata ago
       * @return La teksto de la ŝpruchelpilo
       */
      function leguHelpilonPorAgo($ago) {
         global $kunteksto;
         if($ago == 'elshutu')
            return $kunteksto->leguTradukon('Elŝutu tiun dosieron');
         else
            return parent::leguHelpilonPorAgo($ago);
      }

      /**
       * Liveru la dosierindikon de la piktogramo, kiu reprezentas la tipon de la dosiero
       *
       * Tiu funkcio uzas la agordoj de Pâturage kaj la uzata ŝablono por selekti piktogramon
       * laŭ la tipo de la dosiero.
       *
       * @return La dosierindikon de la piktogramo
       */
      function leguDosierIndikonAlPiktogramo() {
         global $piktogramoj, $kunteksto;
         return $kunteksto->leguDosierIndikonAlPiktogramujo() . '/' . $piktogramoj[$this->_artiklo->leguDosierTipon()];
      }

      /**
       * Liveru la URL-on al la vidigota bildo en la vidaĵo de la dosiero
       *
       * Se la dosiero estas bildo, tiu funkcio liveros la URL-on de la
       * "superfluga" bildo vidigebla en la dosiera vidaĵo aŭ en la albumoj.
       *
       * @return La URL-on de la superfluga bildo por la dosiero
       */
      function leguURLonAlBildSuperflugo() {
         return "bildoj/lum_" . $this->_artiklo->leguKompletanNomon();
      }

      //@}

      /**
       * @name Ŝablona interfaco
       *
       * Tiuj funkcioj estas vokeblaj de la ŝablonaj dosieroj "dosiero.php" kaj "lumbildo.php"
       */

      //@{

      /**
       * Vidigu la atributojn de la dosiero
       *
       * Se la dosiero estas bilda aŭ teksta, ĝia enhavo estos vidigata.
       *
       * Tiu funkcio estas vokebla el la ŝablonaj dosieroj "dosiero.php" kaj "lumbildo.php"
       */
      function vidiguSuperflugon() {
         global $kunteksto;
         switch($this->_artiklo->leguDosierTipon()) {

            case 'bildo':
               PGAranghisto::vidiguBildanLigilon(
                     $this->leguURLonAlBildSuperflugo(),
                     $this->leguURLonPorAgo('elshutu'),
                     $this->leguHelpilonPorAgo('elshutu'),
                     '', 'pg-lumbildo'
                  );
               break;

            case 'teksto':
               PGAranghisto::vidiguPretaranghitanTekston(file_get_contents($kunteksto->leguURLonAlDosiero($this->_artiklo)));
               break;

            default:
               PGAranghisto::malfermuSekcionKunKlaso('pg-artiklo-stato');
               echo $kunteksto->leguTradukon('Tiu dosiertipo ne estas vidigebla');
               PGAranghisto::fermuSekcion();
         }
      }

      //@}
   }
?>
