<?php
/* Ĉi tiu dosiero estas parto de Pâturage
 * 
 * Copyright (C) 2007 - Guillaume Savaton <llumeao@gmail.com>
 * 
 * Pâturage  estas libera programo;  vi  povas  ĝin  pludistribui  kaj/aŭ
 * modifi je la  kondiĉoj de la GNUa Ĝenerala Publika Permesilo, eldonita
 * de «Free Software Foundation», laŭ la versio 2 de tiu Permesilo aŭ, se
 * vi preferas, ajna posta versio.
 * 
 * Ni distribuas  ĉi tiun  programon esperante  ke ĝi estos  utila, tamen
 * SEN IA AJN GARANTIO,  i.a. sen la implica garantio pri SURMERKATIGEBLO
 * aŭ  TAŬGECO POR IU KONKRETA CELO. Pliajn  detalojn  vidu  en  la  GNUa
 * Ĝenerala Publika Permesilo.
 * 
 * Ekzemplero  de  la  GNUa  Ĝenerala Publika    Permesilo   devas   esti
 * liverita al vi kun ĉi tiu programo; ricevis, turnu vin al
 * 
 * Free Software Foundation
 * 51 Franklin Street, Fifth Floor
 * Boston, MA 02110-1301, USA
 * ------------------------------------------------------------------- */
?>
<?php
   require_once('klasoj/kunteksto.php');
   require_once('klasoj/fabriko.php');
   require_once('klasoj/vidajho.php');
   require_once('klasoj/aranghisto.php');
   require_once('klasoj/artiklo.php');
   require_once('klasoj/artikla-vidajho.php');
   require_once('klasoj/etikedo.php');
   require_once('klasoj/etikeda-vidajho.php');

   /**
    * Vidaĵo de la foliumilo
    *
    * Tiu klaso provizas funkcioj por vidigi la ĉefan foliumilon de Pâturage.
    */
   class PGFoliumilaVidajho extends PGVidajho {

      /**
       * @name Paĝa interfaco
       *
       * Tiuj funkcioj estas vokeblaj de la paĝa vidaĵo, kie la foliumilo estos videbla.
       */

      //@{

      /**
       * Vidigu la foliumilon
       *
       * Tiu funkcio vidigas la ĉefan foliumilon de Pâturage.
       * Ĝi uzas la ŝablonan dosieron "foliumilo.php".
       */
      function vidigu() {
         global $kunteksto;
         include($kunteksto->leguDosierIndikonAlShablono('foliumilo'));
      }

      //@}

      /**
       * @name Ŝablona interfaco
       *
       * Tiuj funkcioj estas vokeblaj de la ŝablona dosiero "foliumilo.php".
       */

      //@{

      /**
       * Vidigu la liston de artikloj
       *
       * Tiu funkcio vidigas la liston de artikloj laŭ la selektitaj etikedoj
       * en la foliumilo.
       * En gasta modo, nur la publikaj artikloj estas vidigataj; en uzanta aŭ
       * administra modo, ankaŭ la privataj artikloj estas vidigataj.
       * Por ĉiu artiklo, tiu funkcio akiras vidaĵon el PGFabriko, kaj vokas
       * la funkcion PGArtiklaVidajho::vidiguEnFoliumilo().
       */
      function vidiguListon() {
         global $kunteksto;

         // Ne selektu la privatajn artiklojn, se la uzanto ne ensalutis
         $selektitajArtikloj = PGArtiklo::leguChiujnArtiklojn(!$kunteksto->chuGasto());

         /* Se la paĝo estas vokita kun argumento pri etikedoj,
          * selektu nur la artikloj kun la specifitaj etikedoj */
         if($kunteksto->chuEkzistasArgumentonPriEtikedoj()) {
            $etikedoj = $kunteksto->leguArgumentonPriEtikedoj();
            foreach($etikedoj as $t)
               $selektitajArtikloj = $t->selektuArtiklojn($selektitajArtikloj);
         }

         /* Se la tabelo de selektitaj artikloj estas malplena, vidigu mesaĝon.
          * Alie, akiru vidaĵon el la fabriko por ĉiu selektita artiklo,
          * kaj vidigu ĝin */
         if(count($selektitajArtikloj) == 0) {
            PGAranghisto::malfermuSekcionKunKlaso('pg-foliumilo-stato');
            echo $kunteksto->leguTradukon('Neniu artiklo');
            PGAranghisto::fermuSekcion();
         }
         else {
            foreach($selektitajArtikloj as $artiklo) {
               $artiklaVidajho = PGFabriko::leguVidajhonPorArtiklo($artiklo);
               $artiklaVidajho->vidiguEnFoliumilo();
            }
         }
      }

      /**
       * Vidigu la etikedaron
       *
       * Tiu funkcio uzas la etikedan vidaĵon por vidigi la etikedaron en
       * la foliumilo.
       */
      function vidiguEtikedaron() {
         PGEtikedaVidajho::vidiguEtikedaron();
      }

      /**
       * Vidigu la formularon por ensaluti
       *
       * En gasta reĝimo, tiu funkcio vidigas kampon por tajpi pasvorton.
       * En uzanta aŭ administra reĝimo, tiu funkcio vidigas butonon por elsaluti.
       */
      function vidiguEnsalutFormularon() {
         global $kunteksto;
         if($kunteksto->chuGasto()) {
            PGAranghisto::malfermuFormularon('ensalutu', 'multipart/form-data', $kunteksto->leguURLonPorAgo('ensalutu'), 'post');
            PGAranghisto::vidiguEnigilon($kunteksto->leguTradukon('Pasvorto:'), 'password', 'pasvorto', 'sekreto');
            PGAranghisto::fermuFormularon();
         }
         else {
            PGAranghisto::malfermuFormularon('elsalutu', 'multipart/form-data', $kunteksto->leguURLonPorAgo('elsalutu'), 'post');
            PGAranghisto::malfermuSekcionKunKlaso('pg-kampo-nomo');
            echo $kunteksto->leguTradukon('Konektita kiel ' . $kunteksto->leguEnsalutReghimon());
            PGAranghisto::fermuSekcion();
            PGAranghisto::malfermuSekcionKunKlaso('butono');
            PGAranghisto::vidiguEnigilon('', 'submit', 'elsalutu', $kunteksto->leguTradukon('Elsalutu'));
            PGAranghisto::fermuSekcion();
            PGAranghisto::fermuFormularon();
         }
      }

      //@}
   }
?>
